glue\_genes.glue\_genomics\_data.tifffile\_factory.read\_tifffile\_as\_zarr
===========================================================================

.. currentmodule:: glue_genes.glue_genomics_data.tifffile_factory

.. autofunction:: read_tifffile_as_zarr